@@ -1,8 +1,8 @@
 # Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.
 
-from tinydb import TinyDB, Query
+from tinydb   import TinyDB, Query
 from tabulate import tabulate
-from attrdict import AttrDict
+from .        import SehirNesnesi
 import json, os
 
 BURDAYIZ = os.path.dirname(os.path.abspath(__file__))
@@ -21,9 +21,12 @@ class Sehir(object):
         .tablo(veri:dict) -> str:
         .anahtarlar(veri:dict) -> list:
     """
+    def __repr__(self) -> str:
+        return f"{__class__.__name__} Sınıfı -- Türkiye Cumhuriyeti Devleti Şehirlerini; İl, Plaka, Telefon veya İlçe bilgisinden bulun.."
+
     def __init__(self):
-        "TinyDB Modelini Sorguya Hazırladık."
-        self.db     = TinyDB(f'{BURDAYIZ}/Veriler/sehirler.json')
+        """TinyDB Modelini Sorguya Hazırladık."""
+        self.db     = TinyDB(f'{BURDAYIZ}/Veriler/sehirler.json', encoding="utf-8", ensure_ascii=False, indent=2, sort_keys=False)
         self.sorgu  = Query()
 
     def il(self, il:str) -> dict:
@@ -37,8 +40,7 @@ class Sehir(object):
             dict: {'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']}
         """
         try:
-            sorgu = self.db.search(self.sorgu.il == il.capitalize())[0]
-            return json.loads(json.dumps(sorgu, ensure_ascii=False))
+            return self.db.search(self.sorgu.il == il.capitalize())[0]
         except IndexError:
             return {"Hata": f"'{il}' | diye bir il bulunamadı.."}
 
@@ -53,8 +55,7 @@ class Sehir(object):
             dict: {'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']}
         """
         try:
-            sorgu = self.db.search(self.sorgu.plaka == plaka)[0]
-            return json.loads(json.dumps(sorgu, ensure_ascii=False))
+            return self.db.search(self.sorgu.plaka == plaka)[0]
         except IndexError:
             return {"Hata": f"'{plaka}' | diye bir plaka bulunamadı.."}
 
@@ -69,8 +70,7 @@ class Sehir(object):
             dict: {'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']}
         """
         try:
-            sorgu = self.db.search(self.sorgu.telefon == telefon)[0]
-            return json.loads(json.dumps(sorgu, ensure_ascii=False))
+            return self.db.search(self.sorgu.telefon == telefon)[0]
         except IndexError:
             try:
                 return self.db.search(self.sorgu.telefon.any(str(telefon)))[0]
@@ -88,8 +88,7 @@ class Sehir(object):
             dict: {'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']}
         """
         try:
-            sorgu = self.db.search(self.sorgu.ilceler.any(ilce.capitalize()))[0]
-            return json.loads(json.dumps(sorgu, ensure_ascii=False))
+            return self.db.search(self.sorgu.ilceler.any(ilce.capitalize()))[0]
         except IndexError:
             return {"Hata": f"'{ilce}' | diye bir ilçe bulunamadı.."}
 
@@ -172,10 +171,10 @@ class Sehir(object):
         Dönüş:
             list: ['plaka', 'il', 'telefon', 'buyuksehir_den_beri', 'bolge', 'ilceler']
         """
-        return [anahtar for anahtar in veri.keys()]
+        return list(veri.keys())
 
     @staticmethod
-    def nesne(veri) -> AttrDict:
+    def nesne(veri) -> SehirNesnesi:
         """
         json verisini python nesnesine dönüştürür
 
@@ -183,6 +182,6 @@ class Sehir(object):
             veri : sehir.plaka(17)
 
         Dönüş:
-            AttrDict: AttrDict({'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']})
+            Sehir: SehirNesnesi({'plaka': 17, 'il': 'Çanakkale', 'telefon': 286, 'buyuksehir_den_beri': None, 'bolge': 'Marmara', 'ilceler': ['Ayvacık', 'Bayramiç', 'Biga', 'Bozcaada', 'Çan', 'Eceabat', 'Ezine', 'Gelibolu', 'Gökçeada', 'Lapseki', 'Merkez', 'Yenice']})
         """
-        return AttrDict(veri)
\ No newline at end of file
+        return SehirNesnesi(veri)
\ No newline at end of file
